@@ -10,7 +10,8 @@ from code_loader.contract.datasetclasses import SectionCallableInterface, InputH
     GroundTruthHandler, MetadataHandler, DatasetIntegrationSetup, VisualizerHandler, PreprocessResponse, \
     PreprocessHandler, VisualizerCallableInterface, CustomLossHandler, CustomCallableInterface, PredictionTypeHandler, \
     MetadataSectionCallableInterface, UnlabeledDataPreprocessHandler, CustomLayerHandler, MetricHandler, \
-    ConfusionMatrixCallableInterface, CustomCallableInterfaceMultiArgs, ConfusionMatrixCallableInterfaceMultiArgs
+    ConfusionMatrixCallableInterface, CustomCallableInterfaceMultiArgs, ConfusionMatrixCallableInterfaceMultiArgs, \
+    CustomMultipleReturnCallableInterfaceMultiArgs
 from code_loader.contract.enums import DatasetMetadataType, LeapDataType, MetricEnum
 from code_loader.metrics.default_metrics import metrics_names_to_functions
 from code_loader.utils import to_numpy_return_wrapper
@@ -86,7 +87,9 @@ class LeapBinder:
 
     @typechecked
     def add_custom_metric(self,
-                          function: Union[CustomCallableInterfaceMultiArgs, ConfusionMatrixCallableInterfaceMultiArgs],
+                          function: Union[CustomCallableInterfaceMultiArgs,
+                                          CustomMultipleReturnCallableInterfaceMultiArgs,
+                                          ConfusionMatrixCallableInterfaceMultiArgs],
                           name: str) -> None:
         arg_names = inspect.getfullargspec(function)[0]
         self.setup_container.metrics.append(MetricHandler(name, function, arg_names))
@@ -108,9 +111,8 @@ class LeapBinder:
         self._encoder_names.append(name)
 
     @typechecked
-    def set_metadata(self, function: MetadataSectionCallableInterface, metadata_type: DatasetMetadataType,
-                     name: str) -> None:
-        self.setup_container.metadata.append(MetadataHandler(name, function, metadata_type))
+    def set_metadata(self, function: MetadataSectionCallableInterface, name: str) -> None:
+        self.setup_container.metadata.append(MetadataHandler(name, function))
 
     @typechecked
     def set_custom_layer(self, custom_layer: Type[tf.keras.layers.Layer], name: str) -> None:
